@@ -8,9 +8,11 @@ from term import TermCollection
 from attendance import AttendanceCollection
 from course_grade import CourseGradeCollection
 from enrollment import EnrollmentCollection
+from period import PeriodCollection
+from attendance_code import AttendanceCodeCollection
 
 class Organization(ResourceInstance):
-  subresources = [CourseCollection, SchoolCollection, SectionCollection, StudentCollection, TeacherCollection, TermCollection, AttendanceCollection, CourseGradeCollection, EnrollmentCollection]
+  subresources = [CourseCollection, SchoolCollection, SectionCollection, StudentCollection, TeacherCollection, TermCollection, AttendanceCollection, CourseGradeCollection, EnrollmentCollection, PeriodCollection, AttendanceCodeCollection]
 
 
 class OrganizationCollection(ResourceCollection):
